@@ -155,7 +155,7 @@ sjp.gpt <- function(x,
   # max and all others, so we have proportion
   # between maximux value and rest
   # ------------------------------------
-  mydf$dep <- sjmisc::rec(mydf$dep, "max=1;else=0")
+  mydf$dep <- sjmisc::rec(mydf$dep, recodes = "max=1;else=0")
   # ------------------------------------
   # group data by grouping variable, and inside
   # groups, group the x-variable
